@@ -1,4 +1,3 @@
-import threading
 from typing import Callable, Type, Any, Union, Tuple
 import functools
 from .Functions import areoneof, isoneof, isoneof_strict
@@ -107,9 +106,11 @@ def PartallyImplemented(func: Callable) -> Callable:
     Args:
         func (Callable): the function to decorate
     """
+    from .Colors import warning
+
     @functools.wraps(func)
     def wrapper(*args, **kwargs) -> Any:
-        print(
+        warning(
             f"As marked by the developer, {func.__module__}.{func.__qualname__} may not be fully implemented and might not work propely")
         return func(*args, **kwargs)
     return wrapper
@@ -139,10 +140,10 @@ def overload(*types) -> Callable:
     """decorator for overloading functions\n
     Usage\n-------\n
     @overload(str,str)\n
-    def print_name_and_color(name,color):
+    def print_info(name,color):
         ...\n\n
     @overload(str,[int,float]))\n
-    def print_name_and_age(name,age):
+    def print_info(name,age):
         ...\n\n
 
     also, use 'None' to skip\n\n\n
@@ -166,6 +167,8 @@ def overload(*types) -> Callable:
     types = tuple(types)
 
     def wrapper(func: Callable) -> Callable:
+        if not isinstance(func, Callable):
+            raise TypeError("overload decorator must be used on a callable")
 
         # assign current overload to overload dictionary
         name = f"{func.__module__}.{func.__qualname__}"
@@ -226,21 +229,21 @@ def abstractmethod(func: Callable) -> Callable:
 
 purevirtual = abstractmethod
 
-__virtualization_tables = dict()
+# __virtualization_tables = dict()
 
 
-@NotImplemented
-def virtual(func: Callable) -> Callable:
-    def wrapper(*args, **kwargs):
-        return func(*args, **kwargs)
-    return wrapper
+# @NotImplemented
+# def virtual(func: Callable) -> Callable:
+#     def wrapper(*args, **kwargs):
+#         return func(*args, **kwargs)
+#     return wrapper
 
 
-@NotImplemented
-def override(func: Callable) -> Callable:
-    def wrapper(*args, **kwargs):
-        return func(*args, **kwargs)
-    return wrapper
+# @NotImplemented
+# def override(func: Callable) -> Callable:
+#     def wrapper(*args, **kwargs):
+#         return func(*args, **kwargs)
+#     return wrapper
 
 
 @PartallyImplemented
@@ -261,11 +264,12 @@ def deprecate(obj: Union[str, Callable] = None) -> Callable:
         \tdef foo(...):
         \t\t...
     """
+    from .Colors import warning
     # if callable(obj):
     if isinstance(obj, Callable):
         @functools.wraps(obj)
         def inner(*args, **kwargs) -> Any:
-            print(
+            warning(
                 f"As marked by the developer, {obj.__module__}.{obj.__qualname__} is deprecated")
             return obj(*args, **kwargs)
         return inner
@@ -273,7 +277,7 @@ def deprecate(obj: Union[str, Callable] = None) -> Callable:
     def wrapper(func: Callable) -> Callable:
         @functools.wraps(func)
         def inner(*args, **kwargs) -> Any:
-            print(
+            warning(
                 f"As marked by the developer, {func.__module__}.{func.__qualname__} is deprecated")
             if obj:
                 print(obj)
@@ -287,6 +291,7 @@ def deprecate(obj: Union[str, Callable] = None) -> Callable:
 
 @validate(Callable)
 def atomic(func):
+    import threading
     lock = threading.Lock()
 
     @functools.wraps(func)
@@ -295,6 +300,76 @@ def atomic(func):
             return func(*args, **kwargs)
     return wrapper
 
+
+@validate([int, lambda d: d > 0, "limit_recursion's max_depth must be a positive integer"], None, bool)
+def limit_recursion(max_depth: int, return_value=None, quiet: bool = True):
+    """decorator to limit recursion of functions
+
+    Args:
+        max_depth (int): max recursion depth which is allowed for this function
+        return_value (_type_, optional): The value to return when the limit is reached. Defaults to None.
+            if is None, will return the last (args, kwargs)
+        quiet (bool, optional): wheter to print a warning message. Defaults to True.
+    """
+    import traceback
+    import re
+    from .Colors import warning
+
+    def wrapper(func):
+        @functools.wraps(func)
+        def inner(*args, **kwargs):
+            depth = functools.reduce(
+                lambda count, line:
+                    count + 1 if re.search(f"{func.__name__}\(.*\)$", line)
+                    else count,
+                traceback.format_stack(), 0
+            )
+            if depth >= max_depth:
+                if not quiet:
+                    warning(
+                        f"limit_recursion has limited the number of calls for {func.__module__}.{func.__qualname__} to {max_depth}")
+                if return_value:
+                    return return_value
+                return args, kwargs
+            return func(*args, **kwargs)
+        return inner
+    return wrapper
+
+
+__all__ = [
+    "validate",
+    "NotImplemented",
+    "PartallyImplemented",
+    "memo",
+    "overload",
+    "abstractmethod",
+    "purevirtual",
+    # "virtual",
+    # "override",
+    "deprecate",
+    "atomic",
+    "limit_recursion"
+]
+# def catch(obj) -> Callable:
+#     def logic(func, *args, **kwargs):
+#         try:
+#             return func(*args, **kwargs)
+#         except Exception as e:
+#             name = f"{func.__module__}.{func.__qualname__}(...)"
+#             exp = f"{type(e).__name__}: {e}"
+#             print(f"{name} caught {exp}")
+
+#     def inner(*args, **kwargs):
+#         return logic(obj, *args, **kwargs)
+
+#     if isinstance(obj, Callable):
+#         return inner
+
+#     def wrapper(func):
+#         return inner
+#     return wrapper
+
+
 # @PartallyImplemented
 # @validate(str, Type, bool, Callable, str)
 # def opt(opt_name: str, opt_type: Type, is_required: bool = True, constraints: Callable[[Any], bool] = None, constraints_description: str = None) -> Callable:
