@@ -8,3 +8,8 @@ def atomic_print(*args, **kwargs):
     """exactly the same params and behavior as builtin print(), but behaves atomic-ly
     """
     print(*args, **kwargs)
+
+
+__all__ = [
+    "atomic_print"
+]
